import org.jsoup.Jsoup;
import org.jsoup.nodes.Document;
import org.jsoup.nodes.Element;
import org.jsoup.select.Elements;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
 * News collection job for Associated Press (AP) news feeds, implementing an HTML parsing routine.
 * 
 * @author fhogenboom
 */
public class NewsJobAP extends NewsJob
{

	private static Logger _log = LoggerFactory.getLogger(NewsJobAP.class);

	/**
	 * Constructor.
	 */
	public NewsJobAP()
	{
		super();
	}

	/**
	 * Retrieves the {@link org.slf4j.Logger} of the component.
	 * 
	 * @return {@link org.slf4j.Logger} used for logging system output.
	 */
	protected Logger getLogger()
	{
		return _log;
	}

	/**
	 * Parses the HTML page of a specified link into plain text.
	 * 
	 * @param url Link to be parsed.
	 * @return {@link String} value representing the full text.
	 */
	protected String parseHTML(String url)
	{
		String text = "";
		int retry = 0;
		// While no text has been found and retries are allowed
		while (text.equals("") && retry < max_retry)
		{
			// Increase counter
			retry++;
			try
			{
				// Connect to page
				Document doc = Jsoup.connect(url).get();
				// Grab text contents
				Elements contents = doc.getElementsByClass(txt_cls);
				for (Element content : contents)
				{
					text += content.text();
				}
				if (text.equals(""))
				{
					throw new Exception("Read empty file");
				}
			}
			catch (Exception e)
			{
				_log.error(e.toString() + " -> retrying (" + retry + ")");
			}
		}
		return text;
	}

}